# Fedora Messaging Git Hook messages

A schema package for [Fedora Messaging Git Hook](http://github.com/fedora-infra/fedora-messaging-git-hook).

See the [detailed documentation](https://fedora-messaging.readthedocs.io/en/latest/messages.html) on packaging your schemas.

![PyPI](https://img.shields.io/pypi/v/fedora-messaging-git-hook-messages.svg)
![Supported Python versions](https://img.shields.io/pypi/pyversions/fedora-messaging-git-hook-messages.svg)
![Build status](http://github.com/fedora-infra/fedora-messaging-git-hook-messages/actions/workflows/main.yml/badge.svg?branch=main)
